@@ -11,7 +11,7 @@ from sklearn.ensemble import RandomForestClassifier
 from features import Features
 
 def serve(url, progressBar=True):
-    data = pd.read_csv(r'./data/dataset.csv')
+    data = pd.read_csv(r'./src/data/dataset.csv')
     # Selecting required columns
     x = data.iloc[:,1:-1]
     y = data.iloc[:,-1]
